repowatch — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

Home | Table of contents | Index | Modules
« previous | up | next »

# `repowatch`

## Models

class `Watch`(*args, **kwargs)
  Watch(id, path, rev, component_id)

« <tt class="docutils literal docutils literal docutils literal"><span class="pre">releases</span></tt> | up | <tt class="docutils literal"><span class="pre">simpleauth</span></tt> »

### Table Of Contents

- `repowatch`
  - Models

### Browse

- Prev: `releases`
- Next: `simpleauth`

### You are here:

- Transifex v0.8.0 documentation
  - Table of Contents
    - Transifex Modules
      - `repowatch`

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Last update:

Mar 02, 2010

« previous | up | next »
© Copyright Indifex and the Transifex Community. Last updated on Mar 02, 2010 using Sphinx.